==> devspaces-dashboard-rhel8-container-3.16-27.tar.gz: pkgs.devel.redhat.com/containers/devspaces-dashboard/devspaces-dashboard/packages/dashboard-frontend/src/pages/UserPreferences/GitConfig/Form/SectionUser/Email/__tests__/index.spec.tsx <==
/*
 * Copyright (c) 2018-2024 Red Hat, Inc.
 * This program and the accompanying materials are made
 * available under the terms of the Eclipse Public License 2.0
 * which is available at https://www.eclipse.org/legal/epl-2.0/
 *
 * SPDX-License-Identifier: EPL-2.0
 *
 * Contributors:
 *   Red Hat, Inc. - initial API and implementation
 */

import { ValidatedOptions } from '@patternfly/react-core';
import userEvent from '@testing-library/user-event';
import * as React from 'react';

import getComponentRenderer, { screen } from '@/services/__mocks__/getComponentRenderer';

import { GitConfigUserEmail } from '..';

jest.mock('@/components/InputGroupExtended');

const { createSnapshot, renderComponent } = getComponentRenderer(getComponent);

const mockOnChange = jest.fn();

describe('GitConfigUserEmail', () => {
  afterEach(() => {
    jest.clearAllMocks();
  });

  test('snapshot, not loading', () => {
    const snapshot = createSnapshot('user@che', false);
    expect(snapshot.toJSON()).toMatchSnapshot();
  });
  test('snapshot', () => {
    const snapshot = createSnapshot('user@che', true);
    expect(snapshot.toJSON()).toMatchSnapshot();
  });

  it('should fail validation if value is empty', () => {
    renderComponent('user@che.org', false);

    const textInput = screen.getByRole('textbox');
    userEvent.clear(textInput);

    expect(screen.getByTestId('validated')).toHaveTextContent(ValidatedOptions.error);
  });

  it('should fail validation if value is too long', () => {
    renderComponent('user@che.org', false);

    const textInput = screen.getByRole('textbox');
    userEvent.paste(textInput, 'a'.repeat(129));

    expect(screen.getByTestId('validated')).toHaveTextContent(ValidatedOptions.error);
  });

  it('should fail validation if is not a valid email', () => {
    renderComponent('user@che.org', false);

    const textInput = screen.getByRole('textbox');
    userEvent.paste(textInput, '@test');

    expect(screen.getByTestId('validated')).toHaveTextContent(ValidatedOptions.error);
  });

  it('should re-validate on component update', () => {
    const { reRenderComponent } = renderComponent('', false);

    expect(screen.getByTestId('validated')).toHaveTextContent(ValidatedOptions.error);

    reRenderComponent('user@che.com', false);

    expect(screen.getByTestId('validated')).toHaveTextContent(ValidatedOptions.default);
  });

  it('should handle value changing', () => {
    renderComponent('user@che.org', false);

    const textInput = screen.getByRole('textbox');
    userEvent.paste(textInput, 'a');

    expect(mockOnChange).toHaveBeenCalledWith('user@che.orga', true);
  });
});

function getComponent(value: string, isLoading: boolean): React.ReactElement {
  return <GitConfigUserEmail isLoading={isLoading} value={value} onChange={mockOnChange} />;
}

==> devspaces-dashboard-rhel8-container-3.17-25.tar.gz: pkgs.devel.redhat.com/containers/devspaces-dashboard/devspaces-dashboard/packages/dashboard-frontend/src/pages/UserPreferences/GitConfig/Form/SectionUser/Email/__tests__/index.spec.tsx <==
/*
 * Copyright (c) 2018-2024 Red Hat, Inc.
 * This program and the accompanying materials are made
 * available under the terms of the Eclipse Public License 2.0
 * which is available at https://www.eclipse.org/legal/epl-2.0/
 *
 * SPDX-License-Identifier: EPL-2.0
 *
 * Contributors:
 *   Red Hat, Inc. - initial API and implementation
 */

import { ValidatedOptions } from '@patternfly/react-core';
import userEvent from '@testing-library/user-event';
import * as React from 'react';

import getComponentRenderer, { screen } from '@/services/__mocks__/getComponentRenderer';

import { GitConfigUserEmail } from '..';

jest.mock('@/components/InputGroupExtended');

const { createSnapshot, renderComponent } = getComponentRenderer(getComponent);

const mockOnChange = jest.fn();

describe('GitConfigUserEmail', () => {
  afterEach(() => {
    jest.clearAllMocks();
  });

  test('snapshot, not loading', () => {
    const snapshot = createSnapshot('user@che', false);
    expect(snapshot.toJSON()).toMatchSnapshot();
  });
  test('snapshot', () => {
    const snapshot = createSnapshot('user@che', true);
    expect(snapshot.toJSON()).toMatchSnapshot();
  });

  it('should fail validation if value is empty', async () => {
    renderComponent('user@che.org', false);

    const textInput = screen.getByRole('textbox');
    await userEvent.clear(textInput);

    expect(screen.getByTestId('validated')).toHaveTextContent(ValidatedOptions.error);
  });

  it('should fail validation if value is too long', async () => {
    renderComponent('user@che.org', false);

    const textInput = screen.getByRole('textbox');
    await userEvent.click(textInput);
    await userEvent.paste('a'.repeat(129));

    expect(screen.getByTestId('validated')).toHaveTextContent(ValidatedOptions.error);
  });

  it('should fail validation if is not a valid email', async () => {
    renderComponent('user@che.org', false);

    const textInput = screen.getByRole('textbox');
    await userEvent.click(textInput);
    await userEvent.paste('@test');

    expect(screen.getByTestId('validated')).toHaveTextContent(ValidatedOptions.error);
  });

  it('should re-validate on component update', () => {
    const { reRenderComponent } = renderComponent('', false);

    expect(screen.getByTestId('validated')).toHaveTextContent(ValidatedOptions.error);

    reRenderComponent('user@che.com', false);

    expect(screen.getByTestId('validated')).toHaveTextContent(ValidatedOptions.default);
  });

  it('should handle value changing', async () => {
    renderComponent('user@che.org', false);

    const textInput = screen.getByRole('textbox');
    await userEvent.click(textInput);
    await userEvent.paste('a');

    expect(mockOnChange).toHaveBeenCalledWith('user@che.orga', true);
  });
});

function getComponent(value: string, isLoading: boolean): React.ReactElement {
  return <GitConfigUserEmail isLoading={isLoading} value={value} onChange={mockOnChange} />;
}
